@@ -37,7 +37,8 @@ class ClBuilderPrepareAction(Action):
                     TemplatesError,
                     BuilderError, GitError)
 
-    successMessage = __("Build prepared successfully in {cl_builder_path}")
+    successMessage = __("Build prepared successfully in "
+                        "<font='white'>{cl_builder_path}</font>")
     failedMessage = __("Preparing the build is failed")
     interruptMessage = __("Preparing manually interrupted")
 
